"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DEFAULT_TRANSLATION = {
    '*': (val) => val,
    '9': (val) => val.replace(/[^0-9]+/g, ''),
    A: (val) => val.replace(/[^a-zA-Z]+/g, ''),
    S: (val) => val.replace(/[^a-zA-Z0-9]+/g, ''),
};
const toPattern = (value, mask, translation = DEFAULT_TRANSLATION) => {
    let result = '';
    let maskCharIndex = 0;
    let valueCharIndex = 0;
    while (true) {
        if (maskCharIndex === mask.length)
            break;
        if (valueCharIndex === value.length)
            break;
        const maskChar = mask[maskCharIndex];
        const valueChar = value[valueCharIndex];
        if (maskChar === valueChar) {
            result += maskChar;
            valueCharIndex += 1;
            maskCharIndex += 1;
            continue;
        }
        const translationHandler = translation[maskChar];
        if (!translationHandler) {
            result += maskChar;
            maskCharIndex += 1;
            continue;
        }
        const resolverValue = translationHandler(valueChar || '');
        if (resolverValue === '') {
            valueCharIndex += 1;
            continue;
        }
        else if (resolverValue !== null) {
            result += resolverValue;
            valueCharIndex += 1;
        }
        else {
            result += maskChar;
        }
        maskCharIndex += 1;
    }
    return result;
};
const custom = {
    value: (value, mask, translation) => {
        if (value === '')
            return value;
        const masked = toPattern(value, mask, translation);
        return masked;
    },
};
exports.default = custom;
