"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const custom_1 = __importDefault(require("./custom"));
const helpers_1 = __importDefault(require("./helpers"));
const DEFAULT_SETTINGS = {
    type: 'BRL',
    ddd: '(99) ',
};
const PHONE_8_MASK = '9999-9999';
const PHONE_9_MASK = '99999-9999';
const PHONE_INTERNATIONAL = '+999 999 999 999';
const getMask = (value, settings) => {
    const merged = helpers_1.default.mergeSettings(DEFAULT_SETTINGS, settings);
    if (merged.type === 'INTERNATIONAL')
        return PHONE_INTERNATIONAL;
    let mask = PHONE_8_MASK;
    const withDDD = merged.ddd && merged.ddd.length > 0;
    const use9DigitMask = (() => {
        if (withDDD) {
            const ddd = helpers_1.default.toNumber(merged.ddd);
            const remaining = value.substr(ddd.length);
            return remaining.length >= 9;
        }
        return value.length >= 9;
    })();
    if (use9DigitMask)
        mask = PHONE_9_MASK;
    if (withDDD)
        mask = `${merged.ddd}${mask}`;
    return mask;
};
const phone = {
    raw: (value = '') => helpers_1.default.toNumber(value),
    value: (value = '', settings) => {
        const cleaned = helpers_1.default.toNumber(value);
        const mask = getMask(cleaned, settings);
        return custom_1.default.value(cleaned, mask);
    },
    validate: (value = '', settings) => {
        const cleaned = helpers_1.default.toNumber(value);
        const mask = getMask(cleaned, settings);
        return value.length === mask.length;
    },
};
exports.default = phone;
